<?php
namespace Teknisa\PLA\Modules\Mymeals\Services;

use Doctrine\ORM\EntityManager;
use Teknisa\Model\Planejamento\Entities\Paramtpratserv;
use Geral\Entities\Servoper;
use Teknisa\Model\Planejamento\Entities\Paramservicooper;
use Zeedhi\Framework\DataSource;

class Pla99901ParametrizacaoMymealsService {

    protected $entityManager;
    protected $environment;
    protected $dataSourceManager;

    public function __construct(EntityManager $entityManager, $environment, DataSource\Manager $dataSourceManager)
    {
        $this->entityManager = $entityManager;
        $this->environment = $environment;
        $this->dataSourceManager = $dataSourceManager;
    }

    public function iniciaTransacao(){
        $this->entityManager->beginTransaction();
    }

    public function commit(){
        $this->entityManager->commit();
    }

    public function flush(){
        $this->entityManager->flush();
    }

    public function rollback(){
        $this->entityManager->rollback();
    }

    public function retornaParamtpratserv(){
        return $this->entityManager->getRepository('Teknisa\Model\Planejamento\Entities\Paramtpratserv')
            ->findBy(array("nrorg" => $this->environment->getNrOrgTrab()), array("nrparamtpratserv" => "desc"));
    }

    public function salvaParamservicooper($cdfilial, $cdservfili, $row){
        $paramservicooper = $this->entityManager->getRepository('Teknisa\Model\Planejamento\Entities\Paramservicooper')
            ->findOneBy(array("cdfilial" => $cdfilial, "cdservfili" => $cdservfili, "nrorg" => $this->environment->getNrOrgTrab())); 
        
        if(!$paramservicooper){
            $paramservicooper = new Paramservicooper();
            $paramservicooper->setCdfilial($cdfilial);
            $paramservicooper->setCdservfili($cdservfili);
            $paramservicooper->setCdoperinclusao($row['CDOPERADOR']);
            $paramservicooper->setDtinclusao(new \DateTime());
            $paramservicooper->setNrorg($this->environment->getNrOrgTrab());
            $paramservicooper->setNrorginclusao($this->environment->getNrOrgTrab());
            
        }
        
        $paramservicooper->setIdformaltera($row['IDFORMALTERA']);
        $paramservicooper->setNrdiasalt($row['NRDIASALT']);
        $paramservicooper->setHralteracli($row['HRALTERACLI']);
        $paramservicooper->setVracrescimo($row['VRACRESCIMO']);
        $paramservicooper->setVrreducao($row['VRREDUCAO']);
        $paramservicooper->setIdnotificarefe($row['IDNOTIFICAREFE']);
        $paramservicooper->setDsemailnotif($row['DSEMAILNOTIF']);
        $paramservicooper->setCdoperultatu($row['CDOPERADOR']);
        $paramservicooper->setNrorgultatu($this->environment->getNrOrgTrab());
        $paramservicooper->setDtultatu(new \DateTime());
        
        $this->entityManager->persist($paramservicooper);
    }

    public function insereServoper($cdfilial, $cdservfili, $cdoperador){
        $verificaServoper = $this->entityManager->getRepository('\Geral\Entities\Servoper')
            ->findOneBy(array("cdoperador" => $cdoperador, "cdfilial" => $cdfilial, "cdservfili" => $cdservfili, "nrorg" => $this->environment->getNrOrgTrab()));
        
        if(!$verificaServoper){
            $servoper = new Servoper();

            $servoper->setCdoperador($cdoperador);
            $servoper->setCdfilial($cdfilial);
            $servoper->setCdservfili($cdservfili);
            $servoper->setDtultatusvop(new \DateTime());
            $servoper->setNrorg($this->environment->getNrOrgTrab());
            $servoper->setDtinclusao(new \DateTime());
            $servoper->setDtultatu(new \DateTime());
            $servoper->setNrorginclusao($this->environment->getNrOrgTrab());
            $servoper->setCdoperinclusao($cdoperador);
            $servoper->setNrorgultatu($this->environment->getNrOrgTrab());
            $servoper->setCdoperultatu($cdoperador);
            
            $this->entityManager->persist($servoper);
        } else {
            //throw new \Exception('Parametrização já existente para o serviço.');
            return false;
        }
    }

    public function deletaServoper($cdoperador, $cdfilial, $cdservfili){
        $servoper = $this->entityManager->getRepository('\Geral\Entities\Servoper')
            ->findOneBy(array("cdoperador" => $cdoperador, "cdfilial" => $cdfilial, "cdservfili" => $cdservfili, "nrorg" => $this->environment->getNrOrgTrab()));

        if($servoper){
            $this->entityManager->remove($servoper);
        }
    }

    public function deletaServoperOperador($cdoperador){
        $listaServoper = $this->entityManager->getRepository('\Geral\Entities\Servoper')
            ->findBy(array("cdoperador" => $cdoperador, "nrorg" => $this->environment->getNrOrgTrab()));

        if(count($listaServoper)){
            foreach($listaServoper as $servoper){
                $this->entityManager->remove($servoper);
            }
        }
    }
    
    public function deletaTipoprat($cdfilial, $cdservfili){
        $listaParamtpratserv = $this->entityManager->getRepository('Teknisa\Model\Planejamento\Entities\Paramtpratserv')
            ->findBy(array("cdfilial" => $cdfilial, "cdservfili" => $cdservfili, "nrorg" => $this->environment->getNrOrgTrab()));

        if(count($listaParamtpratserv)){
            foreach($listaParamtpratserv as $paramtpratserv){
                $this->entityManager->remove($paramtpratserv);
            }
        }
    }

    public function insereTipoprat($nrparamtpratserv, $cdfilial, $cdservfili, $cdtipoprat){
            $paramtpratserv = new Paramtpratserv();
            
            $paramtpratserv->setNrparamtpratserv($nrparamtpratserv);
            $paramtpratserv->setCdfilial($cdfilial);
            $paramtpratserv->setCdservfili($cdservfili);
            $paramtpratserv->setCdtipoprat($cdtipoprat);
            $paramtpratserv->setNrorg($this->environment->getNrOrgTrab());
            $paramtpratserv->setDtinclusao(new \DateTime());
            $paramtpratserv->setDtultatu(new \DateTime());
            $paramtpratserv->setNrorginclusao($this->environment->getNrOrgTrab());
            $paramtpratserv->setCdoperinclusao($this->environment->getCdoperador());
            $paramtpratserv->setNrorgultatu($this->environment->getNrOrgTrab());
            $paramtpratserv->setCdoperultatu($this->environment->getCdoperador());
            
            $this->entityManager->persist($paramtpratserv);
    }

    public function retornaServipoPorOperador($row){
        $params = [
            "CDOPERADOR" => $row['CDOPERADOR_FILTRADO'],
            "NRORG"      => $row['NRORG']
        ];
        $sql = "SELECT PARAMSERVICOOPER.NRORG, SERVOPER.CDOPERADOR, SERVICO.CDFILIAL, FILIAL.NMFILIAL AS NMFILIAL, PARAMSERVICOOPER.CDSERVFILI, SERVICO.NMSERVICO AS NMSERVICO, PARAMSERVICOOPER.IDFORMALTERA, SERVICO.HRINICATEN, PARAMSERVICOOPER.HRALTERACLI, PARAMSERVICOOPER.NRDIASALT, PARAMSERVICOOPER.VRACRESCIMO, PARAMSERVICOOPER.VRREDUCAO, PARAMSERVICOOPER.IDNOTIFICAREFE, PARAMSERVICOOPER.DSEMAILNOTIF FROM PARAMSERVICOOPER INNER JOIN SERVICO ON SERVICO.NRORG = PARAMSERVICOOPER.NRORG AND SERVICO.CDFILIAL = PARAMSERVICOOPER.CDFILIAL AND SERVICO.CDSERVFILI = PARAMSERVICOOPER.CDSERVFILI INNER JOIN SERVOPER ON SERVOPER.NRORG = PARAMSERVICOOPER.NRORG AND SERVOPER.CDFILIAL = PARAMSERVICOOPER.CDFILIAL AND SERVOPER.CDSERVFILI = PARAMSERVICOOPER.CDSERVFILI INNER JOIN FILIAL ON FILIAL.NRORG = PARAMSERVICOOPER.NRORG AND FILIAL.CDFILIAL = PARAMSERVICOOPER.CDFILIAL WHERE SERVICO.IDSERVATIV <> 'N' AND SERVOPER.CDOPERADOR = :CDOPERADOR AND PARAMSERVICOOPER.NRORG = :NRORG ORDER BY PARAMSERVICOOPER.CDFILIAL, PARAMSERVICOOPER.CDSERVFILI";
            
        try {
            
            return $this->entityManager->getConnection()->fetchAll($sql, $params);
        
        } catch (\Exception $e) {
            
            throw $e;
        }
    }

}